@@ -19,10 +19,10 @@ def login(key: str=None, id: str =None, pw: str=None) -> (bool, str):
         assert_that(pw).is_not_none()
 
     try:
-        return interface.login(key,id,pw)
+        return interface.login(key,id,pw)[0]
     except (requests.exceptions.ConnectTimeout, requests.exceptions.ConnectionError) as e:
         logger.error(f"Could Login to Server[{interface.get_http_host()}]. Set Server IP/PORT using deepdriver.setting()")
-        return False, None
+        return False
 
 
 
